# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.bar_source_data_administrative_actions_array_inner import BarSourceDataAdministrativeActionsArrayInner
from unicourt.model.bar_source_data_advanced_degree_array_inner import BarSourceDataAdvancedDegreeArrayInner
from unicourt.model.bar_source_data_bar_status_array_inner import BarSourceDataBarStatusArrayInner
from unicourt.model.bar_source_data_board_certifications_array_inner import BarSourceDataBoardCertificationsArrayInner
from unicourt.model.bar_source_data_committees_array_inner import BarSourceDataCommitteesArrayInner
from unicourt.model.bar_source_data_court_history_array_inner import BarSourceDataCourtHistoryArrayInner
from unicourt.model.bar_source_data_court_of_admissions import BarSourceDataCourtOfAdmissions
from unicourt.model.bar_source_data_disciplinary_history_array_inner import BarSourceDataDisciplinaryHistoryArrayInner
from unicourt.model.bar_source_data_discipline_summaries_array_inner import BarSourceDataDisciplineSummariesArrayInner
from unicourt.model.bar_source_data_employment_history_array_inner import BarSourceDataEmploymentHistoryArrayInner
from unicourt.model.bar_source_data_fees_options_array_inner import BarSourceDataFeesOptionsArrayInner
from unicourt.model.bar_source_data_involvements_array_inner import BarSourceDataInvolvementsArrayInner
from unicourt.model.bar_source_data_law_school_array_inner import BarSourceDataLawSchoolArrayInner
from unicourt.model.bar_source_data_name import BarSourceDataName
from unicourt.model.bar_source_data_open_action_status_array_inner import BarSourceDataOpenActionStatusArrayInner
from unicourt.model.bar_source_data_other_jurisdiction_array_inner import BarSourceDataOtherJurisdictionArrayInner
from unicourt.model.bar_source_data_public_hearing_array_inner import BarSourceDataPublicHearingArrayInner
from unicourt.model.bar_source_data_reason_for_inactivation import BarSourceDataReasonForInactivation
from unicourt.model.bar_source_data_related_cases_array_inner import BarSourceDataRelatedCasesArrayInner
from unicourt.model.bar_source_data_source_info import BarSourceDataSourceInfo
from unicourt.model.bar_source_data_statewide_grievance_committee_history_array_inner import BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner
from unicourt.model.bar_source_data_status_history_array_inner import BarSourceDataStatusHistoryArrayInner
from unicourt.model.bar_source_data_ten_year_discipline_array_inner import BarSourceDataTenYearDisciplineArrayInner
from typing import Optional, Set
from typing_extensions import Self

class BarSourceData(BaseModel):
    """
    BarSourceData
    """ # noqa: E501
    object: Optional[Annotated[str, Field(strict=True, max_length=13)]] = 'BarSourceData'
    administrative_actions_array: Optional[List[BarSourceDataAdministrativeActionsArrayInner]] = Field(default=None, alias="administrativeActionsArray")
    admission_type: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="admissionType")
    appellate_court_district: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="appellateCourtDistrict")
    appellate_division_department: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="appellateDivisionDepartment")
    attorney_group: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="attorneyGroup")
    authorized: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    bar_service_class: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="barServiceClass")
    bio: Optional[Annotated[str, Field(strict=True, max_length=5000)]] = None
    board_certifications_array: Optional[List[BarSourceDataBoardCertificationsArrayInner]] = Field(default=None, alias="boardCertificationsArray")
    board_district: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="boardDistrict")
    circuit: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    comments: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    committees_array: Optional[List[BarSourceDataCommitteesArrayInner]] = Field(default=None, alias="committeesArray")
    court_history_array: Optional[List[BarSourceDataCourtHistoryArrayInner]] = Field(default=None, alias="courtHistoryArray")
    court_of_admissions: Optional[BarSourceDataCourtOfAdmissions] = Field(default=None, alias="courtOfAdmissions")
    court_service_email: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="courtServiceEmail")
    disciplinary_history_array: Optional[List[BarSourceDataDisciplinaryHistoryArrayInner]] = Field(default=None, alias="disciplinaryHistoryArray")
    discipline_summaries_array: Optional[List[BarSourceDataDisciplineSummariesArrayInner]] = Field(default=None, alias="disciplineSummariesArray")
    dismissals_array: Optional[List[Annotated[str, Field(strict=True, max_length=250)]]] = Field(default=None, alias="dismissalsArray")
    district: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    employment_history_array: Optional[List[BarSourceDataEmploymentHistoryArrayInner]] = Field(default=None, alias="employmentHistoryArray")
    expiration_date: Optional[datetime] = Field(default=None, alias="expirationDate")
    fees_options_array: Optional[List[BarSourceDataFeesOptionsArrayInner]] = Field(default=None, alias="feesOptionsArray")
    firm_size: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="firmSize")
    firm_website: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = Field(default=None, alias="firmWebsite")
    first_admitted_date: Optional[datetime] = Field(default=None, description="The firstAdmittedDate is the date when an attorney was admitted to the bar for the very first time regardless of which U.S state.", alias="firstAdmittedDate")
    first_admitted_year: Optional[StrictInt] = Field(default=None, alias="firstAdmittedYear")
    home_county: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="homeCounty")
    in_good_standing: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="inGoodStanding")
    insurance: Optional[Annotated[str, Field(strict=True, max_length=500)]] = None
    involvements_array: Optional[List[BarSourceDataInvolvementsArrayInner]] = Field(default=None, alias="involvementsArray")
    judicial_district: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="judicialDistrict")
    juris_type: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="jurisType")
    languages_array: Optional[List[Annotated[str, Field(strict=True, max_length=1000)]]] = Field(default=None, alias="languagesArray")
    last_renewal_date: Optional[datetime] = Field(default=None, alias="lastRenewalDate")
    law_school_array: Optional[List[BarSourceDataLawSchoolArrayInner]] = Field(default=None, alias="lawSchoolArray")
    legal_speciality_array: Optional[List[Annotated[str, Field(strict=True, max_length=250)]]] = Field(default=None, alias="legalSpecialityArray")
    license_type: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="licenseType")
    name: Optional[BarSourceDataName] = None
    next_registration: Optional[datetime] = Field(default=None, alias="nextRegistration")
    next_renewal_date: Optional[datetime] = Field(default=None, alias="nextRenewalDate")
    open_action_status_array: Optional[List[BarSourceDataOpenActionStatusArrayInner]] = Field(default=None, alias="openActionStatusArray")
    other_jurisdiction_array: Optional[List[BarSourceDataOtherJurisdictionArrayInner]] = Field(default=None, alias="otherJurisdictionArray")
    other_name_array: Optional[List[Annotated[str, Field(strict=True, max_length=500)]]] = Field(default=None, alias="otherNameArray")
    parish: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    pending_proceeding_array: Optional[List[Annotated[str, Field(strict=True, max_length=250)]]] = Field(default=None, alias="pendingProceedingArray")
    position: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    practice_area_array: Optional[List[Annotated[str, Field(strict=True, max_length=250)]]] = Field(default=None, alias="practiceAreaArray")
    practice_location_array: Optional[List[Annotated[str, Field(strict=True, max_length=250)]]] = Field(default=None, alias="practiceLocationArray")
    private_law_practice: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="privateLawPractice")
    profile_last_certified: Optional[datetime] = Field(default=None, alias="profileLastCertified")
    public_hearing_array: Optional[List[BarSourceDataPublicHearingArrayInner]] = Field(default=None, alias="publicHearingArray")
    reason_for_inactivation: Optional[BarSourceDataReasonForInactivation] = Field(default=None, alias="reasonForInactivation")
    sections_array: Optional[List[Annotated[str, Field(strict=True, max_length=250)]]] = Field(default=None, alias="sectionsArray")
    services_array: Optional[List[Annotated[str, Field(strict=True, max_length=250)]]] = Field(default=None, alias="servicesArray")
    source_info: Optional[BarSourceDataSourceInfo] = Field(default=None, alias="sourceInfo")
    statewide_grievance_committee_history_array: Optional[List[BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner]] = Field(default=None, alias="statewideGrievanceCommitteeHistoryArray")
    status: Optional[Annotated[str, Field(strict=True, max_length=500)]] = None
    status_date: Optional[datetime] = Field(default=None, alias="statusDate")
    status_history_array: Optional[List[BarSourceDataStatusHistoryArrayInner]] = Field(default=None, alias="statusHistoryArray")
    ten_year_discipline_array: Optional[List[BarSourceDataTenYearDisciplineArrayInner]] = Field(default=None, alias="tenYearDisciplineArray")
    undergraduate_school: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="undergraduateSchool")
    bar_law_firm: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="barLawFirm")
    years_of_practice: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="yearsOfPractice")
    clients_represented_array: Optional[List[Annotated[str, Field(strict=True, max_length=250)]]] = Field(default=None, alias="clientsRepresentedArray")
    status_hint: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, alias="statusHint")
    advanced_degree_array: Optional[List[BarSourceDataAdvancedDegreeArrayInner]] = Field(default=None, alias="advancedDegreeArray")
    bar_status_array: Optional[List[BarSourceDataBarStatusArrayInner]] = Field(default=None, alias="barStatusArray")
    related_cases_array: Optional[List[BarSourceDataRelatedCasesArrayInner]] = Field(default=None, alias="relatedCasesArray")
    __properties: ClassVar[List[str]] = ["object", "administrativeActionsArray", "admissionType", "appellateCourtDistrict", "appellateDivisionDepartment", "attorneyGroup", "authorized", "barServiceClass", "bio", "boardCertificationsArray", "boardDistrict", "circuit", "comments", "committeesArray", "courtHistoryArray", "courtOfAdmissions", "courtServiceEmail", "disciplinaryHistoryArray", "disciplineSummariesArray", "dismissalsArray", "district", "employmentHistoryArray", "expirationDate", "feesOptionsArray", "firmSize", "firmWebsite", "firstAdmittedDate", "firstAdmittedYear", "homeCounty", "inGoodStanding", "insurance", "involvementsArray", "judicialDistrict", "jurisType", "languagesArray", "lastRenewalDate", "lawSchoolArray", "legalSpecialityArray", "licenseType", "name", "nextRegistration", "nextRenewalDate", "openActionStatusArray", "otherJurisdictionArray", "otherNameArray", "parish", "pendingProceedingArray", "position", "practiceAreaArray", "practiceLocationArray", "privateLawPractice", "profileLastCertified", "publicHearingArray", "reasonForInactivation", "sectionsArray", "servicesArray", "sourceInfo", "statewideGrievanceCommitteeHistoryArray", "status", "statusDate", "statusHistoryArray", "tenYearDisciplineArray", "undergraduateSchool", "barLawFirm", "yearsOfPractice", "clientsRepresentedArray", "statusHint", "advancedDegreeArray", "barStatusArray", "relatedCasesArray"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BarSourceData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in administrative_actions_array (list)
        _items = []
        if self.administrative_actions_array:
            for _item in self.administrative_actions_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['administrativeActionsArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in board_certifications_array (list)
        _items = []
        if self.board_certifications_array:
            for _item in self.board_certifications_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['boardCertificationsArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in committees_array (list)
        _items = []
        if self.committees_array:
            for _item in self.committees_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['committeesArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in court_history_array (list)
        _items = []
        if self.court_history_array:
            for _item in self.court_history_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['courtHistoryArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of court_of_admissions
        if self.court_of_admissions:
            _dict['courtOfAdmissions'] = self.court_of_admissions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in disciplinary_history_array (list)
        _items = []
        if self.disciplinary_history_array:
            for _item in self.disciplinary_history_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['disciplinaryHistoryArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in discipline_summaries_array (list)
        _items = []
        if self.discipline_summaries_array:
            for _item in self.discipline_summaries_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['disciplineSummariesArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in employment_history_array (list)
        _items = []
        if self.employment_history_array:
            for _item in self.employment_history_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['employmentHistoryArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in fees_options_array (list)
        _items = []
        if self.fees_options_array:
            for _item in self.fees_options_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['feesOptionsArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in involvements_array (list)
        _items = []
        if self.involvements_array:
            for _item in self.involvements_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['involvementsArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in law_school_array (list)
        _items = []
        if self.law_school_array:
            for _item in self.law_school_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['lawSchoolArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of name
        if self.name:
            _dict['name'] = self.name.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in open_action_status_array (list)
        _items = []
        if self.open_action_status_array:
            for _item in self.open_action_status_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['openActionStatusArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in other_jurisdiction_array (list)
        _items = []
        if self.other_jurisdiction_array:
            for _item in self.other_jurisdiction_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['otherJurisdictionArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in public_hearing_array (list)
        _items = []
        if self.public_hearing_array:
            for _item in self.public_hearing_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['publicHearingArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of reason_for_inactivation
        if self.reason_for_inactivation:
            _dict['reasonForInactivation'] = self.reason_for_inactivation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source_info
        if self.source_info:
            _dict['sourceInfo'] = self.source_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in statewide_grievance_committee_history_array (list)
        _items = []
        if self.statewide_grievance_committee_history_array:
            for _item in self.statewide_grievance_committee_history_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['statewideGrievanceCommitteeHistoryArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in status_history_array (list)
        _items = []
        if self.status_history_array:
            for _item in self.status_history_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['statusHistoryArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in ten_year_discipline_array (list)
        _items = []
        if self.ten_year_discipline_array:
            for _item in self.ten_year_discipline_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['tenYearDisciplineArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in advanced_degree_array (list)
        _items = []
        if self.advanced_degree_array:
            for _item in self.advanced_degree_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['advancedDegreeArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in bar_status_array (list)
        _items = []
        if self.bar_status_array:
            for _item in self.bar_status_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['barStatusArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in related_cases_array (list)
        _items = []
        if self.related_cases_array:
            for _item in self.related_cases_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['relatedCasesArray'] = _items
        # set to None if admission_type (nullable) is None
        # and model_fields_set contains the field
        if self.admission_type is None and "admission_type" in self.model_fields_set:
            _dict['admissionType'] = None

        # set to None if appellate_court_district (nullable) is None
        # and model_fields_set contains the field
        if self.appellate_court_district is None and "appellate_court_district" in self.model_fields_set:
            _dict['appellateCourtDistrict'] = None

        # set to None if appellate_division_department (nullable) is None
        # and model_fields_set contains the field
        if self.appellate_division_department is None and "appellate_division_department" in self.model_fields_set:
            _dict['appellateDivisionDepartment'] = None

        # set to None if attorney_group (nullable) is None
        # and model_fields_set contains the field
        if self.attorney_group is None and "attorney_group" in self.model_fields_set:
            _dict['attorneyGroup'] = None

        # set to None if authorized (nullable) is None
        # and model_fields_set contains the field
        if self.authorized is None and "authorized" in self.model_fields_set:
            _dict['authorized'] = None

        # set to None if bar_service_class (nullable) is None
        # and model_fields_set contains the field
        if self.bar_service_class is None and "bar_service_class" in self.model_fields_set:
            _dict['barServiceClass'] = None

        # set to None if bio (nullable) is None
        # and model_fields_set contains the field
        if self.bio is None and "bio" in self.model_fields_set:
            _dict['bio'] = None

        # set to None if board_district (nullable) is None
        # and model_fields_set contains the field
        if self.board_district is None and "board_district" in self.model_fields_set:
            _dict['boardDistrict'] = None

        # set to None if circuit (nullable) is None
        # and model_fields_set contains the field
        if self.circuit is None and "circuit" in self.model_fields_set:
            _dict['circuit'] = None

        # set to None if comments (nullable) is None
        # and model_fields_set contains the field
        if self.comments is None and "comments" in self.model_fields_set:
            _dict['comments'] = None

        # set to None if court_service_email (nullable) is None
        # and model_fields_set contains the field
        if self.court_service_email is None and "court_service_email" in self.model_fields_set:
            _dict['courtServiceEmail'] = None

        # set to None if district (nullable) is None
        # and model_fields_set contains the field
        if self.district is None and "district" in self.model_fields_set:
            _dict['district'] = None

        # set to None if expiration_date (nullable) is None
        # and model_fields_set contains the field
        if self.expiration_date is None and "expiration_date" in self.model_fields_set:
            _dict['expirationDate'] = None

        # set to None if firm_size (nullable) is None
        # and model_fields_set contains the field
        if self.firm_size is None and "firm_size" in self.model_fields_set:
            _dict['firmSize'] = None

        # set to None if firm_website (nullable) is None
        # and model_fields_set contains the field
        if self.firm_website is None and "firm_website" in self.model_fields_set:
            _dict['firmWebsite'] = None

        # set to None if first_admitted_date (nullable) is None
        # and model_fields_set contains the field
        if self.first_admitted_date is None and "first_admitted_date" in self.model_fields_set:
            _dict['firstAdmittedDate'] = None

        # set to None if first_admitted_year (nullable) is None
        # and model_fields_set contains the field
        if self.first_admitted_year is None and "first_admitted_year" in self.model_fields_set:
            _dict['firstAdmittedYear'] = None

        # set to None if home_county (nullable) is None
        # and model_fields_set contains the field
        if self.home_county is None and "home_county" in self.model_fields_set:
            _dict['homeCounty'] = None

        # set to None if in_good_standing (nullable) is None
        # and model_fields_set contains the field
        if self.in_good_standing is None and "in_good_standing" in self.model_fields_set:
            _dict['inGoodStanding'] = None

        # set to None if insurance (nullable) is None
        # and model_fields_set contains the field
        if self.insurance is None and "insurance" in self.model_fields_set:
            _dict['insurance'] = None

        # set to None if judicial_district (nullable) is None
        # and model_fields_set contains the field
        if self.judicial_district is None and "judicial_district" in self.model_fields_set:
            _dict['judicialDistrict'] = None

        # set to None if juris_type (nullable) is None
        # and model_fields_set contains the field
        if self.juris_type is None and "juris_type" in self.model_fields_set:
            _dict['jurisType'] = None

        # set to None if last_renewal_date (nullable) is None
        # and model_fields_set contains the field
        if self.last_renewal_date is None and "last_renewal_date" in self.model_fields_set:
            _dict['lastRenewalDate'] = None

        # set to None if license_type (nullable) is None
        # and model_fields_set contains the field
        if self.license_type is None and "license_type" in self.model_fields_set:
            _dict['licenseType'] = None

        # set to None if next_registration (nullable) is None
        # and model_fields_set contains the field
        if self.next_registration is None and "next_registration" in self.model_fields_set:
            _dict['nextRegistration'] = None

        # set to None if next_renewal_date (nullable) is None
        # and model_fields_set contains the field
        if self.next_renewal_date is None and "next_renewal_date" in self.model_fields_set:
            _dict['nextRenewalDate'] = None

        # set to None if parish (nullable) is None
        # and model_fields_set contains the field
        if self.parish is None and "parish" in self.model_fields_set:
            _dict['parish'] = None

        # set to None if position (nullable) is None
        # and model_fields_set contains the field
        if self.position is None and "position" in self.model_fields_set:
            _dict['position'] = None

        # set to None if private_law_practice (nullable) is None
        # and model_fields_set contains the field
        if self.private_law_practice is None and "private_law_practice" in self.model_fields_set:
            _dict['privateLawPractice'] = None

        # set to None if profile_last_certified (nullable) is None
        # and model_fields_set contains the field
        if self.profile_last_certified is None and "profile_last_certified" in self.model_fields_set:
            _dict['profileLastCertified'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if status_date (nullable) is None
        # and model_fields_set contains the field
        if self.status_date is None and "status_date" in self.model_fields_set:
            _dict['statusDate'] = None

        # set to None if undergraduate_school (nullable) is None
        # and model_fields_set contains the field
        if self.undergraduate_school is None and "undergraduate_school" in self.model_fields_set:
            _dict['undergraduateSchool'] = None

        # set to None if bar_law_firm (nullable) is None
        # and model_fields_set contains the field
        if self.bar_law_firm is None and "bar_law_firm" in self.model_fields_set:
            _dict['barLawFirm'] = None

        # set to None if years_of_practice (nullable) is None
        # and model_fields_set contains the field
        if self.years_of_practice is None and "years_of_practice" in self.model_fields_set:
            _dict['yearsOfPractice'] = None

        # set to None if status_hint (nullable) is None
        # and model_fields_set contains the field
        if self.status_hint is None and "status_hint" in self.model_fields_set:
            _dict['statusHint'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BarSourceData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'BarSourceData',
            "administrativeActionsArray": [BarSourceDataAdministrativeActionsArrayInner.from_dict(_item) for _item in obj["administrativeActionsArray"]] if obj.get("administrativeActionsArray") is not None else None,
            "admissionType": obj.get("admissionType"),
            "appellateCourtDistrict": obj.get("appellateCourtDistrict"),
            "appellateDivisionDepartment": obj.get("appellateDivisionDepartment"),
            "attorneyGroup": obj.get("attorneyGroup"),
            "authorized": obj.get("authorized"),
            "barServiceClass": obj.get("barServiceClass"),
            "bio": obj.get("bio"),
            "boardCertificationsArray": [BarSourceDataBoardCertificationsArrayInner.from_dict(_item) for _item in obj["boardCertificationsArray"]] if obj.get("boardCertificationsArray") is not None else None,
            "boardDistrict": obj.get("boardDistrict"),
            "circuit": obj.get("circuit"),
            "comments": obj.get("comments"),
            "committeesArray": [BarSourceDataCommitteesArrayInner.from_dict(_item) for _item in obj["committeesArray"]] if obj.get("committeesArray") is not None else None,
            "courtHistoryArray": [BarSourceDataCourtHistoryArrayInner.from_dict(_item) for _item in obj["courtHistoryArray"]] if obj.get("courtHistoryArray") is not None else None,
            "courtOfAdmissions": BarSourceDataCourtOfAdmissions.from_dict(obj["courtOfAdmissions"]) if obj.get("courtOfAdmissions") is not None else None,
            "courtServiceEmail": obj.get("courtServiceEmail"),
            "disciplinaryHistoryArray": [BarSourceDataDisciplinaryHistoryArrayInner.from_dict(_item) for _item in obj["disciplinaryHistoryArray"]] if obj.get("disciplinaryHistoryArray") is not None else None,
            "disciplineSummariesArray": [BarSourceDataDisciplineSummariesArrayInner.from_dict(_item) for _item in obj["disciplineSummariesArray"]] if obj.get("disciplineSummariesArray") is not None else None,
            "dismissalsArray": obj.get("dismissalsArray"),
            "district": obj.get("district"),
            "employmentHistoryArray": [BarSourceDataEmploymentHistoryArrayInner.from_dict(_item) for _item in obj["employmentHistoryArray"]] if obj.get("employmentHistoryArray") is not None else None,
            "expirationDate": obj.get("expirationDate"),
            "feesOptionsArray": [BarSourceDataFeesOptionsArrayInner.from_dict(_item) for _item in obj["feesOptionsArray"]] if obj.get("feesOptionsArray") is not None else None,
            "firmSize": obj.get("firmSize"),
            "firmWebsite": obj.get("firmWebsite"),
            "firstAdmittedDate": obj.get("firstAdmittedDate"),
            "firstAdmittedYear": obj.get("firstAdmittedYear"),
            "homeCounty": obj.get("homeCounty"),
            "inGoodStanding": obj.get("inGoodStanding"),
            "insurance": obj.get("insurance"),
            "involvementsArray": [BarSourceDataInvolvementsArrayInner.from_dict(_item) for _item in obj["involvementsArray"]] if obj.get("involvementsArray") is not None else None,
            "judicialDistrict": obj.get("judicialDistrict"),
            "jurisType": obj.get("jurisType"),
            "languagesArray": obj.get("languagesArray"),
            "lastRenewalDate": obj.get("lastRenewalDate"),
            "lawSchoolArray": [BarSourceDataLawSchoolArrayInner.from_dict(_item) for _item in obj["lawSchoolArray"]] if obj.get("lawSchoolArray") is not None else None,
            "legalSpecialityArray": obj.get("legalSpecialityArray"),
            "licenseType": obj.get("licenseType"),
            "name": BarSourceDataName.from_dict(obj["name"]) if obj.get("name") is not None else None,
            "nextRegistration": obj.get("nextRegistration"),
            "nextRenewalDate": obj.get("nextRenewalDate"),
            "openActionStatusArray": [BarSourceDataOpenActionStatusArrayInner.from_dict(_item) for _item in obj["openActionStatusArray"]] if obj.get("openActionStatusArray") is not None else None,
            "otherJurisdictionArray": [BarSourceDataOtherJurisdictionArrayInner.from_dict(_item) for _item in obj["otherJurisdictionArray"]] if obj.get("otherJurisdictionArray") is not None else None,
            "otherNameArray": obj.get("otherNameArray"),
            "parish": obj.get("parish"),
            "pendingProceedingArray": obj.get("pendingProceedingArray"),
            "position": obj.get("position"),
            "practiceAreaArray": obj.get("practiceAreaArray"),
            "practiceLocationArray": obj.get("practiceLocationArray"),
            "privateLawPractice": obj.get("privateLawPractice"),
            "profileLastCertified": obj.get("profileLastCertified"),
            "publicHearingArray": [BarSourceDataPublicHearingArrayInner.from_dict(_item) for _item in obj["publicHearingArray"]] if obj.get("publicHearingArray") is not None else None,
            "reasonForInactivation": BarSourceDataReasonForInactivation.from_dict(obj["reasonForInactivation"]) if obj.get("reasonForInactivation") is not None else None,
            "sectionsArray": obj.get("sectionsArray"),
            "servicesArray": obj.get("servicesArray"),
            "sourceInfo": BarSourceDataSourceInfo.from_dict(obj["sourceInfo"]) if obj.get("sourceInfo") is not None else None,
            "statewideGrievanceCommitteeHistoryArray": [BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner.from_dict(_item) for _item in obj["statewideGrievanceCommitteeHistoryArray"]] if obj.get("statewideGrievanceCommitteeHistoryArray") is not None else None,
            "status": obj.get("status"),
            "statusDate": obj.get("statusDate"),
            "statusHistoryArray": [BarSourceDataStatusHistoryArrayInner.from_dict(_item) for _item in obj["statusHistoryArray"]] if obj.get("statusHistoryArray") is not None else None,
            "tenYearDisciplineArray": [BarSourceDataTenYearDisciplineArrayInner.from_dict(_item) for _item in obj["tenYearDisciplineArray"]] if obj.get("tenYearDisciplineArray") is not None else None,
            "undergraduateSchool": obj.get("undergraduateSchool"),
            "barLawFirm": obj.get("barLawFirm"),
            "yearsOfPractice": obj.get("yearsOfPractice"),
            "clientsRepresentedArray": obj.get("clientsRepresentedArray"),
            "statusHint": obj.get("statusHint"),
            "advancedDegreeArray": [BarSourceDataAdvancedDegreeArrayInner.from_dict(_item) for _item in obj["advancedDegreeArray"]] if obj.get("advancedDegreeArray") is not None else None,
            "barStatusArray": [BarSourceDataBarStatusArrayInner.from_dict(_item) for _item in obj["barStatusArray"]] if obj.get("barStatusArray") is not None else None,
            "relatedCasesArray": [BarSourceDataRelatedCasesArrayInner.from_dict(_item) for _item in obj["relatedCasesArray"]] if obj.get("relatedCasesArray") is not None else None
        })
        return _obj





# flake8: noqa

# import apis into api package
from unicourt.api.attorney_analytics_api import AttorneyAnalyticsApi
from unicourt.api.authentication_api import AuthenticationApi
from unicourt.api.callback_api import CallbackApi
from unicourt.api.case_analytics_api import CaseAnalyticsApi
from unicourt.api.case_docket_api import CaseDocketApi
from unicourt.api.case_documents_api import CaseDocumentsApi
from unicourt.api.case_export_api import CaseExportApi
from unicourt.api.case_search_api import CaseSearchApi
from unicourt.api.case_tracking_api import CaseTrackingApi
from unicourt.api.case_update_api import CaseUpdateApi
from unicourt.api.court_availability_api import CourtAvailabilityApi
from unicourt.api.court_standards_api import CourtStandardsApi
from unicourt.api.judge_analytics_api import JudgeAnalyticsApi
from unicourt.api.law_firm_analytics_api import LawFirmAnalyticsApi
from unicourt.api.pacer_api import PACERApi
from unicourt.api.pacer_credential_api import PACERCredentialApi
from unicourt.api.party_analytics_api import PartyAnalyticsApi
from unicourt.api.usage_api import UsageApi




# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.case_search_result import CaseSearchResult
from typing import Optional, Set
from typing_extensions import Self

class PACERImportCaseResults(BaseModel):
    """
    PACERImportCaseResults
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=22, strict=True, max_length=22)]] = Field(default='PACERImportCaseResults', description="Name of the object")
    has_only_meta_info: Optional[StrictBool] = Field(default=None, description="This field determines if the UniCourt Content has only meta information. If the value is true and you require to get the latest updates of the case you will need to make a request to the updateCase API.", alias="hasOnlyMetaInfo")
    uni_court_content: Optional[CaseSearchResult] = Field(default=None, alias="uniCourtContent")
    __properties: ClassVar[List[str]] = ["object", "hasOnlyMetaInfo", "uniCourtContent"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PACERImportCaseResults from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of uni_court_content
        if self.uni_court_content:
            _dict['uniCourtContent'] = self.uni_court_content.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PACERImportCaseResults from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'PACERImportCaseResults',
            "hasOnlyMetaInfo": obj.get("hasOnlyMetaInfo"),
            "uniCourtContent": CaseSearchResult.from_dict(obj["uniCourtContent"]) if obj.get("uniCourtContent") is not None else None
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class Address(BaseModel):
    """
    Address object Data Schema
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=7, strict=True, max_length=7)]] = 'Address'
    street_address1: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=250)]] = Field(default=None, description="1st part of the street address.", alias="streetAddress1")
    street_address2: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=150)]] = Field(default=None, description="2nd part of the street address.", alias="streetAddress2")
    city: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=100)]] = Field(default=None, description="City")
    state_name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=100)]] = Field(default='UNKNOWN', description="State Name if present else default value.", alias="stateName")
    state_code: Optional[Annotated[str, Field(min_length=2, strict=True, max_length=2)]] = Field(default=None, description="State Code if the state is a US state else contains null.", alias="stateCode")
    country_name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=100)]] = Field(default='UNKNOWN', description="Country Name if present else default value.", alias="countryName")
    country_code: Optional[Annotated[str, Field(min_length=2, strict=True, max_length=3)]] = Field(default=None, description="ISO 3166-1 alpha-3 (https://en.wikipedia.org/wiki/ISO_3166-1_alpha-3#Officially_assigned_code_elements). Code of the country if country name is present.", alias="countryCode")
    zip: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=10)]] = Field(default=None, description="Zip code of the address.")
    zip4: Optional[Annotated[str, Field(min_length=4, strict=True, max_length=4)]] = Field(default=None, description="4 digit extension of the zip code if the address is a US address.")
    is_visible: Optional[StrictBool] = Field(default=None, description="Boolean indicating if the address is visible or not.", alias="isVisible")
    first_fetch_date: Optional[datetime] = Field(default=None, description="Date at which this record is created in UniCourt.", alias="firstFetchDate")
    last_fetch_date: Optional[datetime] = Field(default=None, description="Date at which this record was updated in UniCourt.", alias="lastFetchDate")
    latitude: Optional[Union[Annotated[float, Field(le=90, strict=True, ge=-90)], Annotated[int, Field(le=90, strict=True, ge=-90)]]] = Field(default=None, description="Coordinates at geographic coordinate system.")
    longitude: Optional[Union[Annotated[float, Field(le=180, strict=True, ge=-180)], Annotated[int, Field(le=180, strict=True, ge=-180)]]] = Field(default=None, description="Coordinates at geographic coordinate system.")
    __properties: ClassVar[List[str]] = ["object", "streetAddress1", "streetAddress2", "city", "stateName", "stateCode", "countryName", "countryCode", "zip", "zip4", "isVisible", "firstFetchDate", "lastFetchDate", "latitude", "longitude"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Address from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if street_address1 (nullable) is None
        # and model_fields_set contains the field
        if self.street_address1 is None and "street_address1" in self.model_fields_set:
            _dict['streetAddress1'] = None

        # set to None if street_address2 (nullable) is None
        # and model_fields_set contains the field
        if self.street_address2 is None and "street_address2" in self.model_fields_set:
            _dict['streetAddress2'] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict['city'] = None

        # set to None if state_code (nullable) is None
        # and model_fields_set contains the field
        if self.state_code is None and "state_code" in self.model_fields_set:
            _dict['stateCode'] = None

        # set to None if country_code (nullable) is None
        # and model_fields_set contains the field
        if self.country_code is None and "country_code" in self.model_fields_set:
            _dict['countryCode'] = None

        # set to None if zip (nullable) is None
        # and model_fields_set contains the field
        if self.zip is None and "zip" in self.model_fields_set:
            _dict['zip'] = None

        # set to None if zip4 (nullable) is None
        # and model_fields_set contains the field
        if self.zip4 is None and "zip4" in self.model_fields_set:
            _dict['zip4'] = None

        # set to None if latitude (nullable) is None
        # and model_fields_set contains the field
        if self.latitude is None and "latitude" in self.model_fields_set:
            _dict['latitude'] = None

        # set to None if longitude (nullable) is None
        # and model_fields_set contains the field
        if self.longitude is None and "longitude" in self.model_fields_set:
            _dict['longitude'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Address from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'Address',
            "streetAddress1": obj.get("streetAddress1"),
            "streetAddress2": obj.get("streetAddress2"),
            "city": obj.get("city"),
            "stateName": obj.get("stateName") if obj.get("stateName") is not None else 'UNKNOWN',
            "stateCode": obj.get("stateCode"),
            "countryName": obj.get("countryName") if obj.get("countryName") is not None else 'UNKNOWN',
            "countryCode": obj.get("countryCode"),
            "zip": obj.get("zip"),
            "zip4": obj.get("zip4"),
            "isVisible": obj.get("isVisible"),
            "firstFetchDate": obj.get("firstFetchDate"),
            "lastFetchDate": obj.get("lastFetchDate"),
            "latitude": obj.get("latitude"),
            "longitude": obj.get("longitude")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.docket_entry_primary_documents import DocketEntryPrimaryDocuments
from unicourt.model.docket_entry_secondary_documents import DocketEntrySecondaryDocuments
from unicourt.model.referenced_docket_number import ReferencedDocketNumber
from unicourt.model.source_structured_data import SourceStructuredData
from typing import Optional, Set
from typing_extensions import Self

class DocketEntry(BaseModel):
    """
    DocketEntry
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=11, strict=True, max_length=11)]] = Field(default='DocketEntry', description="Name of the object")
    sort_order: Optional[StrictInt] = Field(default=None, description="Order number how the dockets have stored in UniCourt.", alias="sortOrder")
    docket_entry_date: Optional[datetime] = Field(default=None, description="Docket Action Date", alias="docketEntryDate")
    docket_number: Optional[StrictInt] = Field(default=None, description="The respective docket entry number which is defined in the court website.", alias="docketNumber")
    docket_badge: Optional[StrictStr] = Field(default=None, description="Docket Badge helps you to know what type of a docket entry it is.", alias="docketBadge")
    text: Optional[StrictStr] = Field(default=None, description="Source Docket Entry")
    text_structured: Optional[SourceStructuredData] = Field(default=None, alias="textStructured")
    referenced_docket_number_array: Optional[List[ReferencedDocketNumber]] = Field(default=None, description="Other Docket Numbers that referenced for a particular docket entry.", alias="referencedDocketNumberArray")
    docket_entry_primary_documents: Optional[DocketEntryPrimaryDocuments] = Field(default=None, alias="docketEntryPrimaryDocuments")
    docket_entry_secondary_documents: Optional[DocketEntrySecondaryDocuments] = Field(default=None, alias="docketEntrySecondaryDocuments")
    last_fetch_date: Optional[Annotated[str, Field(min_length=25, strict=True, max_length=25)]] = Field(default=None, description="When this docket entry was last fetched from the source.", alias="lastFetchDate")
    boundary: Optional[StrictStr] = Field(default=None, description="Determines if it is the first docket entry or the last docket entry. This value will be set only for the first and last docket entry. For other docket entries it will be null. However, this will be set as single_docket_entry when the Case contains only one docket entry.")
    __properties: ClassVar[List[str]] = ["object", "sortOrder", "docketEntryDate", "docketNumber", "docketBadge", "text", "textStructured", "referencedDocketNumberArray", "docketEntryPrimaryDocuments", "docketEntrySecondaryDocuments", "lastFetchDate", "boundary"]

    @field_validator('docket_badge')
    def docket_badge_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DOCKET', 'CHARGE', 'HEARING', 'JUDGEMENT', 'FINANCIAL', 'DISPOSITION', 'SENTENCE', 'BOND', 'BAIL', 'CAUSE_OF_ACTION', 'ARREST', 'WARRANT', 'SUMMON', 'TICKLER', 'OPINION']):
            raise ValueError("must be one of enum values ('DOCKET', 'CHARGE', 'HEARING', 'JUDGEMENT', 'FINANCIAL', 'DISPOSITION', 'SENTENCE', 'BOND', 'BAIL', 'CAUSE_OF_ACTION', 'ARREST', 'WARRANT', 'SUMMON', 'TICKLER', 'OPINION')")
        return value

    @field_validator('boundary')
    def boundary_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['first', 'last', 'single_docket_entry', 'null']):
            raise ValueError("must be one of enum values ('first', 'last', 'single_docket_entry', 'null')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DocketEntry from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of text_structured
        if self.text_structured:
            _dict['textStructured'] = self.text_structured.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in referenced_docket_number_array (list)
        _items = []
        if self.referenced_docket_number_array:
            for _item in self.referenced_docket_number_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['referencedDocketNumberArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of docket_entry_primary_documents
        if self.docket_entry_primary_documents:
            _dict['docketEntryPrimaryDocuments'] = self.docket_entry_primary_documents.to_dict()
        # override the default output from pydantic by calling `to_dict()` of docket_entry_secondary_documents
        if self.docket_entry_secondary_documents:
            _dict['docketEntrySecondaryDocuments'] = self.docket_entry_secondary_documents.to_dict()
        # set to None if docket_number (nullable) is None
        # and model_fields_set contains the field
        if self.docket_number is None and "docket_number" in self.model_fields_set:
            _dict['docketNumber'] = None

        # set to None if boundary (nullable) is None
        # and model_fields_set contains the field
        if self.boundary is None and "boundary" in self.model_fields_set:
            _dict['boundary'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DocketEntry from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'DocketEntry',
            "sortOrder": obj.get("sortOrder"),
            "docketEntryDate": obj.get("docketEntryDate"),
            "docketNumber": obj.get("docketNumber"),
            "docketBadge": obj.get("docketBadge"),
            "text": obj.get("text"),
            "textStructured": SourceStructuredData.from_dict(obj["textStructured"]) if obj.get("textStructured") is not None else None,
            "referencedDocketNumberArray": [ReferencedDocketNumber.from_dict(_item) for _item in obj["referencedDocketNumberArray"]] if obj.get("referencedDocketNumberArray") is not None else None,
            "docketEntryPrimaryDocuments": DocketEntryPrimaryDocuments.from_dict(obj["docketEntryPrimaryDocuments"]) if obj.get("docketEntryPrimaryDocuments") is not None else None,
            "docketEntrySecondaryDocuments": DocketEntrySecondaryDocuments.from_dict(obj["docketEntrySecondaryDocuments"]) if obj.get("docketEntrySecondaryDocuments") is not None else None,
            "lastFetchDate": obj.get("lastFetchDate"),
            "boundary": obj.get("boundary")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class PacerCredentialRequest(BaseModel):
    """
    PacerCredentialRequest
    """ # noqa: E501
    pacer_user_id: Annotated[str, Field(min_length=6, strict=True, max_length=40)] = Field(description="Pacer User Id.", alias="pacerUserId")
    default_pacer_client_code: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=32)]] = Field(default=None, description="This is mandatory if your setting in PACER website is set to Yes for the flag `Require Client Code?` under `Set PACER Billing Preferences` page. The client code is a text field entered by users upon login that can be used to track usage by person, client matter number, or other meaningful entry up to 32 characters, comprising the following:    Alphabetic characters (A-Z or a-z)    Numeric digits (0-9)   Period (.)    Underscore (_)    Hyphen (-)    Slash (/)", alias="defaultPacerClientCode")
    password: Annotated[str, Field(min_length=8, strict=True, max_length=45)] = Field(description="Password.")
    __properties: ClassVar[List[str]] = ["pacerUserId", "defaultPacerClientCode", "password"]

    @field_validator('default_pacer_client_code')
    def default_pacer_client_code_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[a-zA-Z0-9._\-\/]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-zA-Z0-9._\-\/]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PacerCredentialRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if default_pacer_client_code (nullable) is None
        # and model_fields_set contains the field
        if self.default_pacer_client_code is None and "default_pacer_client_code" in self.model_fields_set:
            _dict['defaultPacerClientCode'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PacerCredentialRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pacerUserId": obj.get("pacerUserId"),
            "defaultPacerClientCode": obj.get("defaultPacerClientCode"),
            "password": obj.get("password")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.area_of_law import AreaOfLaw
from typing import Optional, Set
from typing_extensions import Self

class AreaOfLawResponse(BaseModel):
    """
    AreaOfLawResponse
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=17, strict=True, max_length=17)]] = 'AreaOfLawResponse'
    area_of_law_array: Optional[List[AreaOfLaw]] = Field(default=None, alias="areaOfLawArray")
    next_page_api: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=2140)]] = Field(default=None, description="Link to next page.", alias="nextPageAPI")
    previous_page_api: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=2139)]] = Field(default=None, description="Link to previous page.", alias="previousPageAPI")
    page_number: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Page number for which results where obtained.", alias="pageNumber")
    total_pages: Optional[StrictInt] = Field(default=None, description="Total number of pages to obtain all the objects.", alias="totalPages")
    total_count: Optional[StrictInt] = Field(default=None, description="Total number of matches found.", alias="totalCount")
    __properties: ClassVar[List[str]] = ["object", "areaOfLawArray", "nextPageAPI", "previousPageAPI", "pageNumber", "totalPages", "totalCount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AreaOfLawResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in area_of_law_array (list)
        _items = []
        if self.area_of_law_array:
            for _item in self.area_of_law_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['areaOfLawArray'] = _items
        # set to None if next_page_api (nullable) is None
        # and model_fields_set contains the field
        if self.next_page_api is None and "next_page_api" in self.model_fields_set:
            _dict['nextPageAPI'] = None

        # set to None if previous_page_api (nullable) is None
        # and model_fields_set contains the field
        if self.previous_page_api is None and "previous_page_api" in self.model_fields_set:
            _dict['previousPageAPI'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AreaOfLawResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'AreaOfLawResponse',
            "areaOfLawArray": [AreaOfLaw.from_dict(_item) for _item in obj["areaOfLawArray"]] if obj.get("areaOfLawArray") is not None else None,
            "nextPageAPI": obj.get("nextPageAPI"),
            "previousPageAPI": obj.get("previousPageAPI"),
            "pageNumber": obj.get("pageNumber"),
            "totalPages": obj.get("totalPages"),
            "totalCount": obj.get("totalCount")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.associated_so_s_person import AssociatedSoSPerson
from unicourt.model.contact import Contact
from unicourt.model.sos_associated_norm_organization import SOSAssociatedNormOrganization
from unicourt.model.sos_name_change import SOSNameChange
from typing import Optional, Set
from typing_extensions import Self

class SOSData(BaseModel):
    """
    SOSData
    """ # noqa: E501
    object: Optional[Annotated[str, Field(strict=True, max_length=7)]] = 'SOSData'
    sos_number: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, alias="sosNumber")
    state_code: Optional[Annotated[str, Field(strict=True, max_length=2)]] = Field(default=None, alias="stateCode")
    fein: Optional[Annotated[str, Field(strict=True, max_length=16)]] = None
    domestic_registration: Optional[StrictBool] = Field(default=True, alias="domesticRegistration")
    registered_date: Optional[datetime] = Field(default=None, alias="registeredDate")
    status: Optional[Annotated[str, Field(strict=True, max_length=10)]] = None
    is_active: Optional[StrictBool] = Field(default=True, alias="isActive")
    inactivation_date: Optional[datetime] = Field(default=None, alias="inactivationDate")
    associated_so_s_person_array: Optional[List[AssociatedSoSPerson]] = Field(default=None, alias="associatedSoSPersonArray")
    contact: Optional[Contact] = None
    name_changes_array: Optional[List[SOSNameChange]] = Field(default=None, alias="nameChangesArray")
    sos_associated_norm_organization_array: Optional[List[SOSAssociatedNormOrganization]] = Field(default=None, alias="sosAssociatedNormOrganizationArray")
    first_fetch_date: Optional[datetime] = Field(default=None, alias="firstFetchDate")
    last_fetch_date: Optional[datetime] = Field(default=None, alias="lastFetchDate")
    last_fetch_date_with_updates: Optional[datetime] = Field(default=None, description="Last Fetch Date of Organization with Updates.", alias="lastFetchDateWithUpdates")
    __properties: ClassVar[List[str]] = ["object", "sosNumber", "stateCode", "fein", "domesticRegistration", "registeredDate", "status", "isActive", "inactivationDate", "associatedSoSPersonArray", "contact", "nameChangesArray", "sosAssociatedNormOrganizationArray", "firstFetchDate", "lastFetchDate", "lastFetchDateWithUpdates"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Active']):
            raise ValueError("must be one of enum values ('Active')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SOSData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in associated_so_s_person_array (list)
        _items = []
        if self.associated_so_s_person_array:
            for _item in self.associated_so_s_person_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['associatedSoSPersonArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of contact
        if self.contact:
            _dict['contact'] = self.contact.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in name_changes_array (list)
        _items = []
        if self.name_changes_array:
            for _item in self.name_changes_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['nameChangesArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in sos_associated_norm_organization_array (list)
        _items = []
        if self.sos_associated_norm_organization_array:
            for _item in self.sos_associated_norm_organization_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['sosAssociatedNormOrganizationArray'] = _items
        # set to None if sos_number (nullable) is None
        # and model_fields_set contains the field
        if self.sos_number is None and "sos_number" in self.model_fields_set:
            _dict['sosNumber'] = None

        # set to None if fein (nullable) is None
        # and model_fields_set contains the field
        if self.fein is None and "fein" in self.model_fields_set:
            _dict['fein'] = None

        # set to None if registered_date (nullable) is None
        # and model_fields_set contains the field
        if self.registered_date is None and "registered_date" in self.model_fields_set:
            _dict['registeredDate'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if inactivation_date (nullable) is None
        # and model_fields_set contains the field
        if self.inactivation_date is None and "inactivation_date" in self.model_fields_set:
            _dict['inactivationDate'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SOSData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'SOSData',
            "sosNumber": obj.get("sosNumber"),
            "stateCode": obj.get("stateCode"),
            "fein": obj.get("fein"),
            "domesticRegistration": obj.get("domesticRegistration") if obj.get("domesticRegistration") is not None else True,
            "registeredDate": obj.get("registeredDate"),
            "status": obj.get("status"),
            "isActive": obj.get("isActive") if obj.get("isActive") is not None else True,
            "inactivationDate": obj.get("inactivationDate"),
            "associatedSoSPersonArray": [AssociatedSoSPerson.from_dict(_item) for _item in obj["associatedSoSPersonArray"]] if obj.get("associatedSoSPersonArray") is not None else None,
            "contact": Contact.from_dict(obj["contact"]) if obj.get("contact") is not None else None,
            "nameChangesArray": [SOSNameChange.from_dict(_item) for _item in obj["nameChangesArray"]] if obj.get("nameChangesArray") is not None else None,
            "sosAssociatedNormOrganizationArray": [SOSAssociatedNormOrganization.from_dict(_item) for _item in obj["sosAssociatedNormOrganizationArray"]] if obj.get("sosAssociatedNormOrganizationArray") is not None else None,
            "firstFetchDate": obj.get("firstFetchDate"),
            "lastFetchDate": obj.get("lastFetchDate"),
            "lastFetchDateWithUpdates": obj.get("lastFetchDateWithUpdates")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.attorney_law_firm import AttorneyLawFirm
from unicourt.model.attorney_type import AttorneyType
from unicourt.model.contact import Contact
from unicourt.model.party_attorney_associations import PartyAttorneyAssociations
from unicourt.model.possible_norm_attorney import PossibleNormAttorney
from unicourt.model.possible_norm_law_firm import PossibleNormLawFirm
from typing import Optional, Set
from typing_extensions import Self

class Attorney(BaseModel):
    """
    Attorney
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=8, strict=True, max_length=8)]] = Field(default='Attorney', description="Name of the object")
    attorney_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, description="ID for the attorney in this case. This ID is unique within a case and NOT across cases. If the same attorney were to appear in another case this ID would be different.", alias="attorneyId")
    name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=250)]] = Field(default=None, description="Name of the attorney as provided by Court.")
    name_prefix: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, alias="namePrefix")
    first_name: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, description="First name of the attorney. This is normalized by UniCourt.", alias="firstName")
    middle_name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="Middle name of the attorney. This is normalized by UniCourt.", alias="middleName")
    last_name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="Last name of the attorney. This is normalized by UniCourt.", alias="lastName")
    name_suffix: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, alias="nameSuffix")
    contact: Optional[Contact] = None
    attorney_law_firm_array: Optional[Annotated[List[AttorneyLawFirm], Field(max_length=25)]] = Field(default=None, alias="attorneyLawFirmArray")
    bar_number: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, description="The bar enrollment number of an attorney.", alias="barNumber")
    attorney_type: Optional[AttorneyType] = Field(default=None, alias="attorneyType")
    source_attorney_type: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, description="Attorney Type as provided by Court.", alias="sourceAttorneyType")
    is_visible: Optional[StrictBool] = Field(default=None, description="Signifies if the attorney as this attorney type is currently isVisible or not for the case.", alias="isVisible")
    first_fetch_date: Optional[datetime] = Field(default=None, description="When was the attorney first fetched from the court site.", alias="firstFetchDate")
    last_fetch_date: Optional[datetime] = Field(default=None, description="When was the attorney last fetched from the court site.", alias="lastFetchDate")
    party_attorney_associations: Optional[PartyAttorneyAssociations] = Field(default=None, alias="partyAttorneyAssociations")
    possible_norm_attorney_array: Optional[List[PossibleNormAttorney]] = Field(default=None, alias="possibleNormAttorneyArray")
    possible_norm_law_firm_array: Optional[List[PossibleNormLawFirm]] = Field(default=None, description="Possible Norm Lawfirm array for a Attorney.", alias="possibleNormLawFirmArray")
    party_role_group_id_array: Optional[List[Annotated[str, Field(min_length=18, strict=True, max_length=18)]]] = Field(default=None, description="Party Role Group Id for a Attorney.", alias="partyRoleGroupIdArray")
    party_role_id_array: Optional[List[Annotated[str, Field(min_length=18, strict=True, max_length=18)]]] = Field(default=None, description="Party Role Id for a Attorney.", alias="partyRoleIdArray")
    __properties: ClassVar[List[str]] = ["object", "attorneyId", "name", "namePrefix", "firstName", "middleName", "lastName", "nameSuffix", "contact", "attorneyLawFirmArray", "barNumber", "attorneyType", "sourceAttorneyType", "isVisible", "firstFetchDate", "lastFetchDate", "partyAttorneyAssociations", "possibleNormAttorneyArray", "possibleNormLawFirmArray", "partyRoleGroupIdArray", "partyRoleIdArray"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Attorney from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of contact
        if self.contact:
            _dict['contact'] = self.contact.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in attorney_law_firm_array (list)
        _items = []
        if self.attorney_law_firm_array:
            for _item in self.attorney_law_firm_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['attorneyLawFirmArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of attorney_type
        if self.attorney_type:
            _dict['attorneyType'] = self.attorney_type.to_dict()
        # override the default output from pydantic by calling `to_dict()` of party_attorney_associations
        if self.party_attorney_associations:
            _dict['partyAttorneyAssociations'] = self.party_attorney_associations.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in possible_norm_attorney_array (list)
        _items = []
        if self.possible_norm_attorney_array:
            for _item in self.possible_norm_attorney_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['possibleNormAttorneyArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in possible_norm_law_firm_array (list)
        _items = []
        if self.possible_norm_law_firm_array:
            for _item in self.possible_norm_law_firm_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['possibleNormLawFirmArray'] = _items
        # set to None if name_prefix (nullable) is None
        # and model_fields_set contains the field
        if self.name_prefix is None and "name_prefix" in self.model_fields_set:
            _dict['namePrefix'] = None

        # set to None if first_name (nullable) is None
        # and model_fields_set contains the field
        if self.first_name is None and "first_name" in self.model_fields_set:
            _dict['firstName'] = None

        # set to None if middle_name (nullable) is None
        # and model_fields_set contains the field
        if self.middle_name is None and "middle_name" in self.model_fields_set:
            _dict['middleName'] = None

        # set to None if last_name (nullable) is None
        # and model_fields_set contains the field
        if self.last_name is None and "last_name" in self.model_fields_set:
            _dict['lastName'] = None

        # set to None if name_suffix (nullable) is None
        # and model_fields_set contains the field
        if self.name_suffix is None and "name_suffix" in self.model_fields_set:
            _dict['nameSuffix'] = None

        # set to None if bar_number (nullable) is None
        # and model_fields_set contains the field
        if self.bar_number is None and "bar_number" in self.model_fields_set:
            _dict['barNumber'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Attorney from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'Attorney',
            "attorneyId": obj.get("attorneyId"),
            "name": obj.get("name"),
            "namePrefix": obj.get("namePrefix"),
            "firstName": obj.get("firstName"),
            "middleName": obj.get("middleName"),
            "lastName": obj.get("lastName"),
            "nameSuffix": obj.get("nameSuffix"),
            "contact": Contact.from_dict(obj["contact"]) if obj.get("contact") is not None else None,
            "attorneyLawFirmArray": [AttorneyLawFirm.from_dict(_item) for _item in obj["attorneyLawFirmArray"]] if obj.get("attorneyLawFirmArray") is not None else None,
            "barNumber": obj.get("barNumber"),
            "attorneyType": AttorneyType.from_dict(obj["attorneyType"]) if obj.get("attorneyType") is not None else None,
            "sourceAttorneyType": obj.get("sourceAttorneyType"),
            "isVisible": obj.get("isVisible"),
            "firstFetchDate": obj.get("firstFetchDate"),
            "lastFetchDate": obj.get("lastFetchDate"),
            "partyAttorneyAssociations": PartyAttorneyAssociations.from_dict(obj["partyAttorneyAssociations"]) if obj.get("partyAttorneyAssociations") is not None else None,
            "possibleNormAttorneyArray": [PossibleNormAttorney.from_dict(_item) for _item in obj["possibleNormAttorneyArray"]] if obj.get("possibleNormAttorneyArray") is not None else None,
            "possibleNormLawFirmArray": [PossibleNormLawFirm.from_dict(_item) for _item in obj["possibleNormLawFirmArray"]] if obj.get("possibleNormLawFirmArray") is not None else None,
            "partyRoleGroupIdArray": obj.get("partyRoleGroupIdArray"),
            "partyRoleIdArray": obj.get("partyRoleIdArray")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.contact import Contact
from unicourt.model.norm_judge_public_data_aba_ratings import NormJudgePublicDataAbaRatings
from unicourt.model.norm_judge_public_data_bio import NormJudgePublicDataBio
from unicourt.model.norm_judge_public_data_education_array_inner import NormJudgePublicDataEducationArrayInner
from unicourt.model.norm_judge_public_data_judicial_source import NormJudgePublicDataJudicialSource
from unicourt.model.norm_judge_public_data_name_history_array_inner import NormJudgePublicDataNameHistoryArrayInner
from unicourt.model.service_history import ServiceHistory
from typing import Optional, Set
from typing_extensions import Self

class NormJudgePublicData(BaseModel):
    """
    This contains the Judge Public details that is obtained from various sources.
    """ # noqa: E501
    object: Optional[Annotated[str, Field(strict=True, max_length=19)]] = 'NormJudgePublicData'
    judicial_status: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="The judicial status of the Judge", alias="judicialStatus")
    judicial_source: Optional[NormJudgePublicDataJudicialSource] = Field(default=None, alias="judicialSource")
    aba_ratings: Optional[NormJudgePublicDataAbaRatings] = Field(default=None, alias="abaRatings")
    alias_array: Optional[List[Annotated[str, Field(strict=True, max_length=250)]]] = Field(default=None, description="Other Names of the Judge.", alias="aliasArray")
    bio: Optional[NormJudgePublicDataBio] = None
    contact: Optional[Contact] = None
    education_array: Optional[List[NormJudgePublicDataEducationArrayInner]] = Field(default=None, description="The Education History of the judge.", alias="educationArray")
    professional_career_array: Optional[List[Annotated[str, Field(strict=True, max_length=2000)]]] = Field(default=None, description="The non-judicial career history of the judge.", alias="professionalCareerArray")
    service_history_array: Optional[List[ServiceHistory]] = Field(default=None, description="Judicial History of the Judge.", alias="serviceHistoryArray")
    name_history_array: Optional[List[NormJudgePublicDataNameHistoryArrayInner]] = Field(default=None, description="Name changes of the Judge. Change in the official name. Other names go to Alias array.", alias="nameHistoryArray")
    first_fetch_date: Optional[datetime] = Field(default=None, alias="firstFetchDate")
    last_fetch_date: Optional[datetime] = Field(default=None, alias="lastFetchDate")
    last_fetch_date_with_updates: Optional[datetime] = Field(default=None, description="Last Fetch Date of the Judge Update.", alias="lastFetchDateWithUpdates")
    __properties: ClassVar[List[str]] = ["object", "judicialStatus", "judicialSource", "abaRatings", "aliasArray", "bio", "contact", "educationArray", "professionalCareerArray", "serviceHistoryArray", "nameHistoryArray", "firstFetchDate", "lastFetchDate", "lastFetchDateWithUpdates"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NormJudgePublicData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of judicial_source
        if self.judicial_source:
            _dict['judicialSource'] = self.judicial_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of aba_ratings
        if self.aba_ratings:
            _dict['abaRatings'] = self.aba_ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bio
        if self.bio:
            _dict['bio'] = self.bio.to_dict()
        # override the default output from pydantic by calling `to_dict()` of contact
        if self.contact:
            _dict['contact'] = self.contact.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in education_array (list)
        _items = []
        if self.education_array:
            for _item in self.education_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['educationArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in service_history_array (list)
        _items = []
        if self.service_history_array:
            for _item in self.service_history_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['serviceHistoryArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in name_history_array (list)
        _items = []
        if self.name_history_array:
            for _item in self.name_history_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['nameHistoryArray'] = _items
        # set to None if judicial_status (nullable) is None
        # and model_fields_set contains the field
        if self.judicial_status is None and "judicial_status" in self.model_fields_set:
            _dict['judicialStatus'] = None

        # set to None if first_fetch_date (nullable) is None
        # and model_fields_set contains the field
        if self.first_fetch_date is None and "first_fetch_date" in self.model_fields_set:
            _dict['firstFetchDate'] = None

        # set to None if last_fetch_date (nullable) is None
        # and model_fields_set contains the field
        if self.last_fetch_date is None and "last_fetch_date" in self.model_fields_set:
            _dict['lastFetchDate'] = None

        # set to None if last_fetch_date_with_updates (nullable) is None
        # and model_fields_set contains the field
        if self.last_fetch_date_with_updates is None and "last_fetch_date_with_updates" in self.model_fields_set:
            _dict['lastFetchDateWithUpdates'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NormJudgePublicData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'NormJudgePublicData',
            "judicialStatus": obj.get("judicialStatus"),
            "judicialSource": NormJudgePublicDataJudicialSource.from_dict(obj["judicialSource"]) if obj.get("judicialSource") is not None else None,
            "abaRatings": NormJudgePublicDataAbaRatings.from_dict(obj["abaRatings"]) if obj.get("abaRatings") is not None else None,
            "aliasArray": obj.get("aliasArray"),
            "bio": NormJudgePublicDataBio.from_dict(obj["bio"]) if obj.get("bio") is not None else None,
            "contact": Contact.from_dict(obj["contact"]) if obj.get("contact") is not None else None,
            "educationArray": [NormJudgePublicDataEducationArrayInner.from_dict(_item) for _item in obj["educationArray"]] if obj.get("educationArray") is not None else None,
            "professionalCareerArray": obj.get("professionalCareerArray"),
            "serviceHistoryArray": [ServiceHistory.from_dict(_item) for _item in obj["serviceHistoryArray"]] if obj.get("serviceHistoryArray") is not None else None,
            "nameHistoryArray": [NormJudgePublicDataNameHistoryArrayInner.from_dict(_item) for _item in obj["nameHistoryArray"]] if obj.get("nameHistoryArray") is not None else None,
            "firstFetchDate": obj.get("firstFetchDate"),
            "lastFetchDate": obj.get("lastFetchDate"),
            "lastFetchDateWithUpdates": obj.get("lastFetchDateWithUpdates")
        })
        return _obj


